@@ -809,11 +809,14 @@ class TextInputField(QLineEdit):
         super().__init__()
         self._name = name
         DEBUG and LOGGER.debug(f"{default = }, {type(default)=}")
-        self._default = str(default)
+        self._default = None if default is None else str(default)
         self._placeholder_text = placeholder_text
         self.setObjectName(name)
         self.setPlaceholderText(self._placeholder_text or self._default)
 
+        if default is None:
+            return
+
         # Create a context menu entry to set the default value
 
         self.setContextMenuPolicy(Qt.CustomContextMenu)
@@ -940,6 +943,7 @@ class ArgumentsPanel(QScrollArea):
                 grid.addWidget(type_hint, idx, 2, alignment=Qt.AlignVCenter)
 
         vbox.addLayout(grid)
+        vbox.addWidget(QLabel(f"Return value(s) will be captured in and overwrite '{self.function.__ui_capture_response__}'."))
 
         hbox = QHBoxLayout()
         button_group = QButtonGroup()
